/*
 * Copyright 2010 Tilburg University
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

package nl.uvt.pdproxy;

import java.util.*;

public interface IStore {
  /**
   * Retrieves a list of person IDs.
   * 
   * @return a list of person IDs
   */
  public List<String> getPersonIds()
  throws StoreException;
  
  /**
   * Retrieves a person from a store.
   * 
   * @param id the identifier of this person
   * @return a Person object
   * @throws UnknownObjectException if the person cannot be found in the store
   * @throws StoreException if the back-end storage solution throws exceptions
   */
  public Person getPerson(String id)
  throws UnknownObjectException, StoreException;
  
  /**
   * Returns the age of the data in the store in milliseconds.
   * 
   * @param id
   * @return age in milliseconds
   * @throws UnknownObjectException if the person cannot be found in the store
   * @throws StoreException if the back-end storage solution throws exceptions
   */
  public long getPersonFileAge(String id)
  throws UnknownObjectException, StoreException;
  
  /**
   * Stores a person.
   * 
   * @param allowOverwrite allowed to overwrite an existing document? True=yes, false=no
   * @throws ObjectAlreadyExistsException if the person is known in the store and overwriting is not allowed
   * @throws StoreException if the back-end storage solution throws exceptions
   */
  public void storePerson(Person person, boolean allowOverwrite)
  throws ObjectAlreadyExistsException, StoreException;

  /**
   * Removes a person from a store.
   * 
   * @param id
   * @throws UnknownObjectException if the person cannot be found in the store
   * @throws StoreException if the back-end storage solution throws exceptions
   */
  public void removePerson(String id)
  throws UnknownObjectException, StoreException;
}
